@@ -16,7 +16,6 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #import "GdkQuartzNSWindow.h"
 #include "gdkquartzwindow.h"
 #include "gdkdnd-quartz.h"
@@ -24,14 +23,6 @@
 
 @implementation GdkQuartzNSWindow
 
-- (void)windowWillClose:(NSNotification*)notification
-{
-  // Clears the delegate when window is going to be closed; since EL
-  // Capitan it is possible that the methods of delegate would get
-  // called after the window has been closed.
-  [self setDelegate:nil];
-}
-
 -(BOOL)windowShouldClose:(id)sender
 {
   GdkWindow *window = [[self contentView] gdkWindow];
@@ -75,7 +66,6 @@
 {
   GdkWindow *window = [[self contentView] gdkWindow];
 
-  gdk_synthesize_window_state (window, 0, GDK_WINDOW_STATE_FOCUSED);
   _gdk_quartz_events_update_focus_window (window, TRUE);
 }
 
@@ -84,7 +74,6 @@
   GdkWindow *window = [[self contentView] gdkWindow];
 
   _gdk_quartz_events_update_focus_window (window, FALSE);
-  gdk_synthesize_window_state (window, GDK_WINDOW_STATE_FOCUSED, 0);
 }
 
 -(void)windowDidBecomeMain:(NSNotification *)aNotification
@@ -120,27 +109,15 @@
   inMove = YES;
 }
 
-
-#ifdef AVAILABLE_MAC_OS_X_VERSION_10_12_AND_LATER
-#define NSLeftMouseUp NSEventTypeLeftMouseUp
-#define NSLeftMouseDragged NSEventTypeLeftMouseDragged
-#define NSMouseEntered NSEventTypeMouseEntered
-#endif
-
 -(void)sendEvent:(NSEvent *)event
 {
   switch ([event type])
     {
     case NSLeftMouseUp:
-    {
-      double time = ((double)[event timestamp]) * 1000.0;
-
-      _gdk_quartz_events_break_all_grabs (time);
       inManualMove = NO;
       inManualResize = NO;
       inMove = NO;
       break;
-    }
 
     case NSLeftMouseDragged:
       if ([self trackManualMove] || [self trackManualResize])
@@ -159,53 +136,11 @@
   return inMove;
 }
 
--(void)checkSendEnterNotify
-{
-  GdkWindow *window = [[self contentView] gdkWindow];
-  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (window->impl);
-
-  /* When a new window has been created, and the mouse
-   * is in the window area, we will not receive an NSMouseEntered
-   * event.  Therefore, we synthesize an enter notify event manually.
-   */
-  if (!initialPositionKnown)
-    {
-      initialPositionKnown = YES;
-
-      if (NSPointInRect ([NSEvent mouseLocation], [self frame]))
-        {
-          NSEvent *event;
-
-          event = [NSEvent enterExitEventWithType: NSMouseEntered
-                                         location: [self mouseLocationOutsideOfEventStream]
-                                    modifierFlags: 0
-                                        timestamp: [[NSApp currentEvent] timestamp]
-                                     windowNumber: [impl->toplevel windowNumber]
-                                          context: NULL
-                                      eventNumber: 0
-                                   trackingNumber: [impl->view trackingRect]
-                                         userData: nil];
-
-          [NSApp postEvent:event atStart:NO];
-        }
-    }
-}
-
 -(void)windowDidMove:(NSNotification *)aNotification
 {
   GdkWindow *window = [[self contentView] gdkWindow];
   GdkEvent *event;
 
-  gboolean maximized = gdk_window_get_state (window) & GDK_WINDOW_STATE_MAXIMIZED;
-
-  /* In case the window is changed when maximized remove the maximized state */
-  if (maximized && !inMaximizeTransition && !NSEqualRects (lastMaximizedFrame, [self frame]))
-    {
-      gdk_synthesize_window_state (window,
-                                   GDK_WINDOW_STATE_MAXIMIZED,
-                                   0);
-    }
-
   _gdk_quartz_window_update_position (window);
 
   /* Synthesize a configure event */
@@ -217,8 +152,6 @@
   event->configure.height = window->height;
 
   _gdk_event_queue_append (gdk_display_get_default (), event);
-
-  [self checkSendEnterNotify];
 }
 
 -(void)windowDidResize:(NSNotification *)aNotification
@@ -226,15 +159,6 @@
   NSRect content_rect = [self contentRectForFrameRect:[self frame]];
   GdkWindow *window = [[self contentView] gdkWindow];
   GdkEvent *event;
-  gboolean maximized = gdk_window_get_state (window) & GDK_WINDOW_STATE_MAXIMIZED;
-
-  /* see same in windowDidMove */
-  if (maximized && !inMaximizeTransition && !NSEqualRects (lastMaximizedFrame, [self frame]))
-    {
-      gdk_synthesize_window_state (window,
-                                   GDK_WINDOW_STATE_MAXIMIZED,
-                                   0);
-    }
 
   window->width = content_rect.size.width;
   window->height = content_rect.size.height;
@@ -257,19 +181,9 @@
   event->configure.height = window->height;
 
   _gdk_event_queue_append (gdk_display_get_default (), event);
-
-  [self checkSendEnterNotify];
 }
 
--(id)initWithContentRect:(NSRect)contentRect
-#if MAC_OS_X_VERSION_MIN_REQUIRED < 101200
-               styleMask:(NSUInteger)styleMask
-#else
-               styleMask:(NSWindowStyleMask)styleMask
-#endif
-                 backing:(NSBackingStoreType)backingType
-                   defer:(BOOL)flag
-                  screen:(NSScreen *)screen
+-(id)initWithContentRect:(NSRect)contentRect styleMask:(NSUInteger)styleMask backing:(NSBackingStoreType)backingType defer:(BOOL)flag screen:(NSScreen *)screen
 {
   self = [super initWithContentRect:contentRect
 	                  styleMask:styleMask
@@ -364,8 +278,6 @@
     [impl->toplevel orderFront:nil];
 
   inShowOrHide = NO;
-
-  [self checkSendEnterNotify];
 }
 
 - (void)hide
@@ -376,54 +288,10 @@
   inShowOrHide = YES;
   [impl->toplevel orderOut:nil];
   inShowOrHide = NO;
-
-  initialPositionKnown = NO;
-}
-
-- (NSPoint)convertPointToScreen:(NSPoint)point
-{
-#if MAC_OS_X_VERSION_MAX_ALLOWED >= 101400
-  if (gdk_quartz_osx_version () >= GDK_OSX_MOJAVE)
-    {
-      return [super convertPointToScreen: point];
-    }
-#endif
-  if (gdk_quartz_osx_version () >= GDK_OSX_LION)
-    {
-      NSRect inrect = NSMakeRect (point.x, point.y, 0.0, 0.0);
-      NSRect outrect = [self convertRectToScreen: inrect];
-      return (NSPoint)((CGRect)outrect).origin;
-    }
-
-#if MAC_OS_X_VERSION_MIN_REQUIRED < 1070
-  return [self convertBaseToScreen:point];
-#endif
-}
-
-- (NSPoint)convertPointFromScreen:(NSPoint)point
-{
-#if MAC_OS_X_VERSION_MAX_ALLOWED >= 101400
-  if (gdk_quartz_osx_version () >= GDK_OSX_MOJAVE)
-    {
-      return [super convertPointFromScreen: point];
-    }
-#endif
-  if (gdk_quartz_osx_version () >= GDK_OSX_LION)
-    {
-      NSRect inrect = NSMakeRect (point.x, point.y, 0.0, 0.0);
-      NSRect outrect = [self convertRectFromScreen: inrect];
-      return (NSPoint)((CGRect)outrect).origin;
-    }
-
-#if MAC_OS_X_VERSION_MIN_REQUIRED < 1070
-  return [self convertScreenToBase:point];
-#endif
 }
 
 - (BOOL)trackManualMove
 {
-  GdkWindow *window = [[self contentView] gdkWindow];
-  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (window->impl);
   NSPoint currentLocation;
   NSPoint newOrigin;
   NSRect screenFrame = [[NSScreen mainScreen] visibleFrame];
@@ -432,28 +300,19 @@
   if (!inManualMove)
     return NO;
 
-  currentLocation = [self convertPointToScreen:[self mouseLocationOutsideOfEventStream]];
+  currentLocation = [self convertBaseToScreen:[self mouseLocationOutsideOfEventStream]];
   newOrigin.x = currentLocation.x - initialMoveLocation.x;
   newOrigin.y = currentLocation.y - initialMoveLocation.y;
 
   /* Clamp vertical position to below the menu bar. */
-  if (newOrigin.y + windowFrame.size.height - impl->shadow_top > screenFrame.origin.y + screenFrame.size.height)
-    newOrigin.y = screenFrame.origin.y + screenFrame.size.height - windowFrame.size.height + impl->shadow_top;
+  if (newOrigin.y + windowFrame.size.height > screenFrame.origin.y + screenFrame.size.height)
+    newOrigin.y = screenFrame.origin.y + screenFrame.size.height - windowFrame.size.height;
 
   [self setFrameOrigin:newOrigin];
 
   return YES;
 }
 
-/* Used by gdkevents-quartz.c to decide if our sendEvent() handler above
- * will see the event or if it will be subjected to standard processing
- * by GDK.
-*/
--(BOOL)isInManualResizeOrMove
-{
-  return inManualResize || inManualMove;
-}
-
 -(void)beginManualMove
 {
   NSRect frame = [self frame];
@@ -463,88 +322,50 @@
 
   inManualMove = YES;
 
-  initialMoveLocation = [self convertPointToScreen:[self mouseLocationOutsideOfEventStream]];
+  initialMoveLocation = [self convertBaseToScreen:[self mouseLocationOutsideOfEventStream]];
   initialMoveLocation.x -= frame.origin.x;
   initialMoveLocation.y -= frame.origin.y;
 }
 
 - (BOOL)trackManualResize
 {
-  NSPoint mouse_location;
-  NSRect new_frame;
-  float mdx, mdy, dw, dh, dx, dy;
+  NSPoint currentLocation;
+  NSRect newFrame;
+  float dx, dy;
   NSSize min_size;
 
   if (!inManualResize || inTrackManualResize)
     return NO;
 
   inTrackManualResize = YES;
-  mouse_location = [self convertPointToScreen:[self mouseLocationOutsideOfEventStream]];
-  mdx = initialResizeLocation.x - mouse_location.x;
-  mdy = initialResizeLocation.y - mouse_location.y;
 
-  /* Set how a mouse location delta translates to changes in width,
-   * height and position.
-   */
-  dw = dh = dx = dy = 0.0;
-  if (resizeEdge == GDK_WINDOW_EDGE_EAST ||
-      resizeEdge == GDK_WINDOW_EDGE_NORTH_EAST ||
-      resizeEdge == GDK_WINDOW_EDGE_SOUTH_EAST)
-    {
-      dw = -1.0;
-    }
-  if (resizeEdge == GDK_WINDOW_EDGE_NORTH ||
-      resizeEdge == GDK_WINDOW_EDGE_NORTH_WEST ||
-      resizeEdge == GDK_WINDOW_EDGE_NORTH_EAST)
-    {
-      dh = -1.0;
-    }
-  if (resizeEdge == GDK_WINDOW_EDGE_SOUTH ||
-      resizeEdge == GDK_WINDOW_EDGE_SOUTH_WEST ||
-      resizeEdge == GDK_WINDOW_EDGE_SOUTH_EAST)
-    {
-      dh = 1.0;
-      dy = -1.0;
-    }
-  if (resizeEdge == GDK_WINDOW_EDGE_WEST ||
-      resizeEdge == GDK_WINDOW_EDGE_NORTH_WEST ||
-      resizeEdge == GDK_WINDOW_EDGE_SOUTH_WEST)
-    {
-      dw = 1.0;
-      dx = -1.0;
-    }
+  currentLocation = [self convertBaseToScreen:[self mouseLocationOutsideOfEventStream]];
+  currentLocation.x -= initialResizeFrame.origin.x;
+  currentLocation.y -= initialResizeFrame.origin.y;
 
-  /* Apply changes to the frame captured when we started resizing */
-  new_frame = initialResizeFrame;
-  new_frame.origin.x += mdx * dx;
-  new_frame.origin.y += mdy * dy;
-  new_frame.size.width += mdx * dw;
-  new_frame.size.height += mdy * dh;
+  dx = currentLocation.x - initialResizeLocation.x;
+  dy = -(currentLocation.y - initialResizeLocation.y);
+
+  newFrame = initialResizeFrame;
+  newFrame.size.width = initialResizeFrame.size.width + dx;
+  newFrame.size.height = initialResizeFrame.size.height + dy;
 
-  /* In case the resulting window would be too small reduce the
-   * change to both size and position.
-   */
   min_size = [self contentMinSize];
-
-  if (new_frame.size.width < min_size.width)
-    {
-      if (dx)
-        new_frame.origin.x -= min_size.width - new_frame.size.width;
-      new_frame.size.width = min_size.width;
-    }
-
-  if (new_frame.size.height < min_size.height)
-    {
-      if (dy)
-        new_frame.origin.y -= min_size.height - new_frame.size.height;
-      new_frame.size.height = min_size.height;
-    }
+  if (newFrame.size.width < min_size.width)
+    newFrame.size.width = min_size.width;
+  if (newFrame.size.height < min_size.height)
+    newFrame.size.height = min_size.height;
 
   /* We could also apply aspect ratio:
-     new_frame.size.height = new_frame.size.width / [self aspectRatio].width * [self aspectRatio].height;
+     newFrame.size.height = newFrame.size.width / [self aspectRatio].width * [self aspectRatio].height;
   */
 
-  [self setFrame:new_frame display:YES];
+  dy = newFrame.size.height - initialResizeFrame.size.height;
+
+  newFrame.origin.x = initialResizeFrame.origin.x;
+  newFrame.origin.y = initialResizeFrame.origin.y - dy;
+
+  [self setFrame:newFrame display:YES];
 
   /* Let the resizing be handled by GTK+. */
   if (g_main_context_pending (NULL))
@@ -555,16 +376,17 @@
   return YES;
 }
 
--(void)beginManualResize:(GdkWindowEdge)edge
+-(void)beginManualResize
 {
   if (inMove || inManualMove || inManualResize)
     return;
 
   inManualResize = YES;
-  resizeEdge = edge;
 
   initialResizeFrame = [self frame];
-  initialResizeLocation = [self convertPointToScreen:[self mouseLocationOutsideOfEventStream]];
+  initialResizeLocation = [self convertBaseToScreen:[self mouseLocationOutsideOfEventStream]];
+  initialResizeLocation.x -= initialResizeFrame.origin.x;
+  initialResizeLocation.y -= initialResizeFrame.origin.y;
 }
 
 
@@ -630,7 +452,7 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
 
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
 {
-  GdkSeat *seat = NULL;
+  GdkDeviceManager *device_manager;
   GdkEvent *event;
   GdkWindow *window;
 
@@ -642,10 +464,10 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
 
   window = [[self contentView] gdkWindow];
 
-  current_context->display = gdk_window_get_display (window);
+  device_manager = gdk_display_get_device_manager (gdk_display_get_default ());
+  gdk_drag_context_set_device (current_context,
+                               gdk_device_manager_get_client_pointer (device_manager));
 
-  seat = gdk_display_get_default_seat (gdk_display_get_default ());
-  gdk_drag_context_set_device (current_context, gdk_seat_get_pointer (seat));
   event = gdk_event_new (GDK_DRAG_ENTER);
   event->dnd.window = g_object_ref (window);
   event->dnd.send_event = FALSE;
@@ -653,7 +475,6 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   event->dnd.time = GDK_CURRENT_TIME;
 
   gdk_event_set_device (event, gdk_drag_context_get_device (current_context));
-  gdk_event_set_seat (event, gdk_device_get_seat (gdk_drag_context_get_device (current_context)));
 
   _gdk_event_emit (event);
 
@@ -684,7 +505,6 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   event->dnd.time = GDK_CURRENT_TIME;
 
   gdk_event_set_device (event, gdk_drag_context_get_device (current_context));
-  gdk_event_set_seat (event, gdk_device_get_seat (gdk_drag_context_get_device (current_context)));
 
   _gdk_event_emit (event);
 
@@ -697,7 +517,7 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
 - (NSDragOperation)draggingUpdated:(id <NSDraggingInfo>)sender
 {
   NSPoint point = [sender draggingLocation];
-  NSPoint screen_point = [self convertPointToScreen:point];
+  NSPoint screen_point = [self convertBaseToScreen:point];
   GdkEvent *event;
   int gx, gy;
 
@@ -713,7 +533,6 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   event->dnd.y_root = gy;
 
   gdk_event_set_device (event, gdk_drag_context_get_device (current_context));
-  gdk_event_set_seat (event, gdk_device_get_seat (gdk_drag_context_get_device (current_context)));
 
   _gdk_event_emit (event);
 
@@ -725,7 +544,7 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
 - (BOOL)performDragOperation:(id <NSDraggingInfo>)sender
 {
   NSPoint point = [sender draggingLocation];
-  NSPoint screen_point = [self convertPointToScreen:point];
+  NSPoint screen_point = [self convertBaseToScreen:point];
   GdkEvent *event;
   int gy, gx;
 
@@ -741,7 +560,6 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   event->dnd.y_root = gy;
 
   gdk_event_set_device (event, gdk_drag_context_get_device (current_context));
-  gdk_event_set_seat (event, gdk_device_get_seat (gdk_drag_context_get_device (current_context)));
 
   _gdk_event_emit (event);
 
@@ -761,8 +579,6 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
 - (void)draggedImage:(NSImage *)anImage endedAt:(NSPoint)aPoint operation:(NSDragOperation)operation
 {
   GdkEvent *event;
-  GdkScreen *screen;
-  GdkDevice *device;
 
   g_assert (_gdk_quartz_drag_source_context != NULL);
 
@@ -771,36 +587,8 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   event->dnd.send_event = FALSE;
   event->dnd.context = g_object_ref (_gdk_quartz_drag_source_context);
 
-  screen = gdk_window_get_screen (event->dnd.window);
-
-  if (screen)
-    {
-      GList* windows, *list;
-      gint gx, gy;
-
-      event->dnd.context->dest_window = NULL;
-
-      windows = gdk_screen_get_toplevel_windows (screen);
-      _gdk_quartz_window_nspoint_to_gdk_xy (aPoint, &gx, &gy);
-
-      for (list = windows; list; list = list->next)
-        {
-          GdkWindow* win = (GdkWindow*) list->data;
-          gint wx, wy;
-          gint ww, wh;
-
-          gdk_window_get_root_origin (win, &wx, &wy);
-          ww = gdk_window_get_width (win);
-          wh = gdk_window_get_height (win);
-
-          if (gx > wx && gy > wy && gx <= wx + ww && gy <= wy + wh)
-            event->dnd.context->dest_window = win;
-        }
-    }
-
-  device = gdk_drag_context_get_device (_gdk_quartz_drag_source_context);
-  gdk_event_set_device (event, device);
-  gdk_event_set_seat (event, gdk_device_get_seat (device));
+  gdk_event_set_device (event,
+                        gdk_drag_context_get_device (_gdk_quartz_drag_source_context));
 
   _gdk_event_emit (event);
 
@@ -810,108 +598,4 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   _gdk_quartz_drag_source_context = NULL;
 }
 
-#ifdef AVAILABLE_MAC_OS_X_VERSION_10_7_AND_LATER
-#if MAC_OS_X_VERSION_MIN_REQUIRED < 101200
-typedef enum
-{
- GDK_QUARTZ_FULL_SCREEN_MASK = NSFullScreenWindowMask,
-} GdkQuartzFullScreen;
-#else
-typedef enum
-{
- GDK_QUARTZ_FULL_SCREEN_MASK = NSWindowStyleMaskFullScreen,
-} GdkQuartzFullScreen;
-#endif
-- (void)setStyleMask:(NSUInteger)styleMask
-{
-  gboolean was_fullscreen;
-  gboolean is_fullscreen;
-
-  was_fullscreen = (([self styleMask] & GDK_QUARTZ_FULL_SCREEN_MASK) != 0);
-
-  [super setStyleMask:styleMask];
-
-  is_fullscreen = (([self styleMask] & GDK_QUARTZ_FULL_SCREEN_MASK) != 0);
-
-  if (was_fullscreen != is_fullscreen)
-    _gdk_quartz_window_update_fullscreen_state ([[self contentView] gdkWindow]);
-}
-
-#endif
-
-- (NSRect)constrainFrameRect:(NSRect)frameRect toScreen:(NSScreen *)screen
-{
-  NSRect rect;
-  GdkWindow *window = [[self contentView] gdkWindow];
-  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (window->impl);
-
-  /* Allow the window to move up "shadow_top" more than normally allowed
-   * by the default impl. This makes it possible to move windows with
-   * client side shadow right up to the screen's menu bar. */
-  rect = [super constrainFrameRect:frameRect toScreen:screen];
-  if (frameRect.origin.y > rect.origin.y)
-    rect.origin.y = MIN (frameRect.origin.y, rect.origin.y + impl->shadow_top);
-
-  return rect;
-}
-
-- (NSRect)windowWillUseStandardFrame:(NSWindow *)nsWindow
-                        defaultFrame:(NSRect)newFrame
-{
-  NSRect screenFrame = [[self screen] visibleFrame];
-  GdkWindow *window = [[self contentView] gdkWindow];
-  gboolean maximized = gdk_window_get_state (window) & GDK_WINDOW_STATE_MAXIMIZED;
-
-  if (!maximized)
-    return screenFrame;
-  else
-    return lastUnmaximizedFrame;
-}
-
-- (BOOL)windowShouldZoom:(NSWindow *)nsWindow
-                 toFrame:(NSRect)newFrame
-{
-
-  GdkWindow *window = [[self contentView] gdkWindow];
-  gboolean maximized = gdk_window_get_state (window) & GDK_WINDOW_STATE_MAXIMIZED;
-
-  if (maximized)
-    {
-      lastMaximizedFrame = newFrame;
-      gdk_synthesize_window_state (window,
-                                   GDK_WINDOW_STATE_MAXIMIZED,
-                                   0);
-    }
-  else
-    {
-      lastUnmaximizedFrame = [nsWindow frame];
-      gdk_synthesize_window_state (window,
-                                   0,
-                                   GDK_WINDOW_STATE_MAXIMIZED);
-    }
-
-  inMaximizeTransition = YES;
-  return YES;
-}
-
--(void)windowDidEndLiveResize:(NSNotification *)aNotification
-{
-  inMaximizeTransition = NO;
-}
-
--(NSSize)window:(NSWindow *)window willUseFullScreenContentSize:(NSSize)proposedSize
-{
-  return [[window screen] frame].size;
-}
-
--(void)windowWillEnterFullScreen:(NSNotification *)aNotification
-{
-  lastUnfullscreenFrame = [self frame];
-}
-
--(void)windowWillExitFullScreen:(NSNotification *)aNotification
-{
-  [self setFrame:lastUnfullscreenFrame display:YES];
-}
-
 @end
